Learn R Programming

BayesNI (version 0.1)

BayesNI-package: Semiparametric Bayesian Noninfereiority Testing

Description

This package implements a Bayesian testing procedure for noninfeiority trials with binary endpoints. The prior is constructed based on Bernstein polynomials with options for both informative and non-informative prior. The critical value of the test statistic Bayes factor is determined by minimizing total weighted error criteria.

Arguments

Details

Package:
BayesNI
Type:
Package
Version:
1.0
Date:
2011-11-08
License:
GPL-2
LazyLoad:
yes

References

Osman M. and Ghosh S. K. (2011) Semiparametric Bayesian Testing Procedure for Non-inferiority Trials with Binary Endpoints. Journal of Biopharmaceutical Statistics, 21, 920-937.

See Also

NA

Examples

Run this code
bayesNI(x1=97,x2=98,n1=107,n2=106, dm='OR',rho=0.5, m=20,zeta=0.025, TWE=1)

Run the code above in your browser using DataLab