Usage
bayesNI(x1, x2, n1, n2, dm = 'OR', rho, m = 10, noninform.prior = TRUE,
w1, w2, TWE = 1, zeta = 0.5, plot.prior = FALSE)Arguments
x1
The number of success events in the group 1
x2
The number of success events in the group 2
n1
The total number of subjects in the group 1
n2
The total number of subjects in the group 2
dm
The dissimilarity measure of two binomial parameters: "RD" risk difference ; "RR" relative risk ;
"OR" odds ratio (default value)
rho
Noninferiority boundary
m
The order of Bernstein polynomials (default value m=10)
noninform.prior
"TRUE" (default) for using noninformative prior to determines weights in the mixture prior; "FALSE" user-specified weights in the mixture prior based on prior information
w1
If noninform.prior=FALSE, a user-specified vector of weights for the prior of theta_1. The length of this vector should be m.
w2
If noninform.prior=FALSE, a user-specified vector of weights for the prior of theta_2. The length of this vector should be m.
TWE
1 (default value): total weighted error conditioned on the hypotheses; 2 : total weighted error conditioned on the decisions
zeta
The weight the total weighted criteria
plot.prior
future functionality, under development.